from django.db import models

from .transaction import TransactionLog
from .base import BaseModelAbstract


class PaymentVendor(BaseModelAbstract, models.Model):
    type = models.CharField(max_length=30, blank=True, null=True)
    name = models.CharField(max_length=30, blank=True, null=True)
    accountNo = models.CharField(db_column='accountNo', max_length=255,
                                 blank=True, null=True)
    accountName = models.CharField(db_column='accountName',
                                   max_length=255, blank=True, null=True)
    ref = models.CharField(max_length=30, blank=True, null=True)
    logo = models.CharField(max_length=255, blank=True, null=True)

    class Meta:
        db_table = 'PaymentVendors'


class Payment(BaseModelAbstract, models.Model):
    orderId = models.CharField(db_column='orderId', max_length=255,
                               blank=True,
                               null=True)  # Field name made lowercase.
    transactionRef = models.CharField(
        db_column='transactionRef', max_length=255, blank=True, null=True)
    paymentRef = models.CharField(db_column='paymentRef', max_length=255,
                                  blank=True, null=True)
    transactionLog = models.ForeignKey(TransactionLog, models.SET_NULL,
                                       blank=True, null=True)
    paymentVendor = models.ForeignKey(PaymentVendor, models.SET_NULL,
                                      blank=True, null=True)
    # paymentType = models.ForeignKey(PaymentType, models.SET_NULL,
    #                                 blank=True, null=True)
    paymentJson = models.JSONField(db_column='paymentJSON', blank=True,
                                   null=True)  # Field name made lowercase.
    channel = models.CharField(max_length=255, blank=True, null=True)

    class Meta:
        db_table = 'Payments'




from django.db import models
from .user import User
from .base import BaseModelAbstract
from .work_order_service import WorkOrderService


class TransactionLog(BaseModelAbstract, models.Model):
    transactionRef = models.CharField(unique=True, max_length=255)
    paymentRef = models.CharField(db_column='paymentRef', max_length=255,
                                  blank=True, null=True)
    paymentVendor = models.ForeignKey(
        "PaymentVendor", models.SET_NULL,
        blank=True, null=True)
    service = models.ForeignKey(WorkOrderService, models.SET_NULL,
                                blank=True, null=True)
    serviceDescription = models.TextField(
        db_column='serviceDescription', blank=True, null=True)
    platform = models.CharField(max_length=30, blank=True, null=True)
    requestJson = models.JSONField(
        db_column='requestJSON', blank=True, null=True)
    responseJson = models.JSONField(
        db_column='responseJSON', blank=True, null=True)
    amount = models.DecimalField(decimal_places=2, max_digits=15, default=0)
    isPaid = models.BooleanField(default=False) 
    status = models.CharField(max_length=30, blank=True, null=True)
    vendorStatus = models.CharField(max_length=30, blank=True, null=True)
    callbackJson = models.JSONField(db_column='callbackJSON', blank=True, 
                                    null=True)  # Field name made lowercase.
    verifyJson = models.JSONField(db_column='verifyJSON', blank=True, 
                                  null=True)  # Field name made lowercase.
    webhookJson = models.JSONField(db_column='webhookJSON', blank=True, 
                                   null=True)  # Field name made lowercase.
    recipient = models.ForeignKey(User, models.SET_NULL, blank=True, 
                                  null=True, 
                                  related_name="received_transactions")
    name = models.CharField(max_length=255, blank=True, null=True)
    email = models.EmailField(blank=True, null=True)

    class Meta:
        db_table = 'TransactionLogs'



from django.db import models

from .base import BaseModelAbstract
from .user import User


class Wallet(BaseModelAbstract, models.Model):
    createdBy = None
    recipientCode = models.CharField(
        db_column='recipientCode', max_length=255, blank=True, null=True)
    recipient = models.JSONField(blank=True, null=True)
    user = models.OneToOneField(User, models.CASCADE, null=False, 
                                blank=False, related_name="wallet")
    name = models.CharField(max_length=255, blank=True, null=True)
    balance = models.DecimalField(default=0, max_digits=15, decimal_places=2)

    class Meta:
        db_table = 'Wallets'


class WalletHistory(BaseModelAbstract, models.Model):
    wallet = models.ForeignKey(Wallet, models.SET_NULL, blank=True, null=True)
    amount = models.DecimalField(default=0, max_digits=15, decimal_places=2)
    description = models.CharField(max_length=255, blank=True, null=True)
    type = models.CharField(max_length=30, blank=True, null=True)
    requestJson = models.JSONField(db_column='requestJSON', blank=True,
                                   null=True)
    transferCode = models.CharField(db_column='transferCode',
                                    max_length=255, blank=True, null=True)
    isCompleted = models.BooleanField(db_column='isCompleted', default=False)

    class Meta:
        db_table = 'WalletHistories'

